==> huaweicloudsdkiec-3.1.137-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/coverage_site_instance.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CoverageSiteInstance:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'site': 'str',
        'demands': 'list[DemandInstance]'
    }

    attribute_map = {
        'site': 'site',
        'demands': 'demands'
    }

    def __init__(self, site=None, demands=None):
        """CoverageSiteInstance

        The model defined in huaweicloud sdk

        :param site: 站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。
        :type site: str
        :param demands: 租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。
        :type demands: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        
        

        self._site = None
        self._demands = None
        self.discriminator = None

        self.site = site
        self.demands = demands

    @property
    def site(self):
        """Gets the site of this CoverageSiteInstance.

        站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。

        :return: The site of this CoverageSiteInstance.
        :rtype: str
        """
        return self._site

    @site.setter
    def site(self, site):
        """Sets the site of this CoverageSiteInstance.

        站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。

        :param site: The site of this CoverageSiteInstance.
        :type site: str
        """
        self._site = site

    @property
    def demands(self):
        """Gets the demands of this CoverageSiteInstance.

        租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。

        :return: The demands of this CoverageSiteInstance.
        :rtype: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        return self._demands

    @demands.setter
    def demands(self, demands):
        """Sets the demands of this CoverageSiteInstance.

        租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。

        :param demands: The demands of this CoverageSiteInstance.
        :type demands: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        self._demands = demands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CoverageSiteInstance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiec-3.1.145-py2.py3-none-any.whl: huaweicloudsdkiec/v1/model/coverage_site_instance.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CoverageSiteInstance:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'site': 'str',
        'demands': 'list[DemandInstance]'
    }

    attribute_map = {
        'site': 'site',
        'demands': 'demands'
    }

    def __init__(self, site=None, demands=None):
        r"""CoverageSiteInstance

        The model defined in huaweicloud sdk

        :param site: 站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。
        :type site: str
        :param demands: 租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。
        :type demands: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        
        

        self._site = None
        self._demands = None
        self.discriminator = None

        self.site = site
        self.demands = demands

    @property
    def site(self):
        r"""Gets the site of this CoverageSiteInstance.

        站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。

        :return: The site of this CoverageSiteInstance.
        :rtype: str
        """
        return self._site

    @site.setter
    def site(self, site):
        r"""Sets the site of this CoverageSiteInstance.

        站点ID。 具体信息可通过调用“查询边缘站点列表”来查询。

        :param site: The site of this CoverageSiteInstance.
        :type site: str
        """
        self._site = site

    @property
    def demands(self):
        r"""Gets the demands of this CoverageSiteInstance.

        租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。

        :return: The demands of this CoverageSiteInstance.
        :rtype: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        return self._demands

    @demands.setter
    def demands(self, demands):
        r"""Sets the demands of this CoverageSiteInstance.

        租户需求数量列表。表示租户发放资源站点的运营商和发放的资源组的数量。

        :param demands: The demands of this CoverageSiteInstance.
        :type demands: list[:class:`huaweicloudsdkiec.v1.DemandInstance`]
        """
        self._demands = demands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CoverageSiteInstance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
